//	popGrowl v1.3, Copyright 2014, Joe Mottershaw, https://github.com/joemottershaw/
//	==============================================================================

	;(function($, window, document, undefined) {
		var pluginName = 'popGrowl',
			defaults = {
				id: 'pop-growl-container',
				vPosition: 'top',
				hPosition: 'right',
				type: 'default',
				title: null,
				text: null,
				html: null,
				sticky: false,
				duration: 4000,
				easing: 'easeOutQuart',
				speed: 600,
				pauseOnHover: true,
				callbackInit: function() {},
				callbackAdd: function() {},
				callbackClick: function() {},
				callbackRemove: function() {}
			};

		function popGrowl(element, options) {
			$this = this,
			this.element = element,
			this.$element = $(this.element);

			this.options = $.extend({}, defaults, options);

			this._defaults = defaults;
			this._name = pluginName;

			if (jQuery.ui)
				_easing = this.options.easing;
			else
				_easing = 'linear';

			this.init();
		}

		popGrowl.prototype = {
			init: function() {
				// Callback
					this.options.callbackInit.call(this);

				// Create container
					if ($('#' + this.options.id).size() === 0)
						$('body').append('<div id="' + this.options.id + '" class="pop-growl pop-growl-' + this.options.vPosition + '-' + this.options.hPosition + '"></div>');

				// Add notification
					$this.addNotification();
			},

			addNotification: function() {
				// Callback
					this.options.callbackAdd.call(this);

				// Create notification
					if (this.options.html)
						var	$notification = $('<div class="pop-growl-notification ' + this.options.type + '"> ' + this.options.html + '</div>');
					else
						var	$notification = $('<div class="pop-growl-notification ' + this.options.type + '"><span class="pop-growl-notification-title">' + this.options.title + '</span><span class="pop-growl-notification-message">' + this.options.text + '</span></div>');

				// Set positions
					if (this.options.vPosition == 'top')
						var vPos = 'top';
					else
						var vPos = 'bottom';

					if (this.options.hPosition == 'left')
						var hPos = 'left';
					else
						var hPos = 'right';

				// Add notification
					if (vPos == 'top')
						$('#' + this.options.id).append($notification);
					else
						$('#' + this.options.id).prepend($notification);

					if (hPos == 'left')
						$notification
							.css({ 'left': '-' + $('#' + this.options.id).width() + 'px' })
							.fadeIn({ queue: false, duration: this.options.speed })
							.animate({ 'left': '0' }, { duration: this.options.speed, easing: _easing });
					else
						$notification
							.css({ 'right': '-' + $('#' + this.options.id).width() + 'px' })
							.fadeIn({ queue: false, duration: this.options.speed })
							.animate({ 'right': '0' }, { duration: this.options.speed, easing: _easing });

				// Timer
					if (!this.options.sticky) {
						var timeout;

						if (this.options.pauseOnHover) {
							function pauseOnHover() {
								if (!timeout) {
									timeout = setTimeout(function () {
										$this.removeNotification($notification, vPos, hPos);
									}, $this.options.duration);
								}
							}

							pauseOnHover();

							$notification.hover(function() {
								if (timeout) {
									clearTimeout(timeout);
									timeout = null;
								}
							}, function() {
								pauseOnHover();
							});
						} else {
							timeout = setTimeout(function() {
								$this.removeNotification($notification, vPos, hPos);
							}, this.options.duration);
						}
					}

				// Remove
					$notification.on('click', function() {
						$this.options.callbackClick.call(this);

						$this.removeNotification($notification, vPos, hPos);
					});
			},

			removeNotification: function($notification, vPos, hPos) {
				// Callback
					this.options.callbackRemove.call(this);

				// Notification height
					if (vPos == 'top')
						var	notificationHeight = $notification.outerHeight();
					else
						var	notificationHeight = $notification.outerHeight(true);

				// Remove
					$notification.fadeOut({ queue: false, duration: this.options.speed });

					if (hPos == 'left')
						if (vPos == 'top')
							$notification.animate({ 'left': '-' + $('#' + this.options.id).width() + 'px', 'margin-bottom': '-' + notificationHeight + 'px' }, this.options.speed, _easing, function() { $notification.remove(); });
						else
							$notification.animate({ 'left': '-' + $('#' + this.options.id).width() + 'px', 'margin-top': '-' + notificationHeight + 'px' }, this.options.speed, _easing, function() { $notification.remove(); });
					else
						if (vPos == 'top')
							$notification.animate({ 'right': '-' + $('#' + this.options.id).width() + 'px', 'margin-bottom': '-' + notificationHeight + 'px' }, this.options.speed, _easing, function() { $notification.remove(); });
						else
							$notification.animate({ 'right': '-' + $('#' + this.options.id).width() + 'px', 'margin-top': '-' + notificationHeight + 'px' }, this.options.speed, _easing, function() { $notification.remove(); });
			}
		};
		
		$.fn[pluginName] = function(options) {
			if (!$.data(this, pluginName))
				$.data(this, pluginName, new popGrowl(this, options));
		};
	})(jQuery, window, document);